import * as React from "react";
import * as css from "classnames";
import config from "../config";
import { Field, ReduxFormInput, ReduxFormMeta } from "redux-form";

// import "semantic-ui-css/components/input.css";

interface IProps {
  classes?: string;
  placeholder?: string;
  label?: string;
  icon?: string;
  iconPosition?: string;
  children?: any;
  inputClasses?: string;
  type?: string;
  leftLabel?: string;
  rightLabel?: string;
  inline?: boolean;
  search?: boolean;
  disabled?: boolean;
  readOnly?: boolean;
  name?: string;
  input?: ReduxFormInput;
  meta?: ReduxFormMeta;
}

class Input extends React.Component<IProps, {}> {
  render() {
    let type = this.props.type ? this.props.type : "text";

    return (
      <div className={css("field", { inline: this.props.inline })}>
        { this.props.label ? <label>{ config.i18n(this.props.label) }</label> : null }
        <div className={css("ui",
          this.props.iconPosition,
          { icon: this.props.icon },
          { right: this.props.rightLabel },
          { labeled: this.props.leftLabel || this.props.rightLabel },
          { search: this.props.search },
          { disabled: this.props.disabled },
          this.props.classes, "input") }>
          { this.props.leftLabel ? <div className="ui label">{ this.props.leftLabel }</div> : null }
          <input
            ref="input"
            type={type}
            className={this.props.inputClasses}
            placeholder={config.i18n(this.props.placeholder)}
            onChange={ this.props.input.onChange }
            value={this.props.input.value}
            onFocus={this.props.input.onFocus}
            onDragStart={this.props.input.onDragStart}
            onDrop={this.props.input.onDrop}
            onBlur={this.props.input.onBlur}
            readOnly={this.props.readOnly}
          />
          { this.props.icon ? <i className={css(this.props.icon, "icon")} /> : null }
          { this.props.rightLabel ? <div className="ui label">{ config.i18n(this.props.rightLabel) }</div> : null }
        </div>
        { this.props.meta.touched && this.props.meta.error && <div className="redux-form-error">{this.props.meta.error}</div>}
      </div>
    );
  }
}

export default (props: IProps) => (
  <Field name={props.name} component={Input} {...props} />
);