import * as React from "react";
import * as css from "classnames";
import config from "../config";
import jss from 'jss';

import { IProps, default as TextArea } from "./textarea";

const styleSheet = jss.createStyleSheet({
  boxes: {
    display: 'table',
    width: '100%',
    height: '100%',
    '& .box': {
      'display': 'table-cell',
      'width': '50%',
      'max-width': '0'
    },
    '& .box1': {
      'padding-right': '6px',
    },
    '& .box2': {
      'padding-left': '6px',
      'border': '1px solid #ddd',
      'border-radius': '4px'
    },
    '& .preview': {
      height: '100%',
      overflow: 'auto',
      'box-sizing': 'content-box'
    }
  },

}).attach();
const jssClasses = styleSheet.classes;

interface IState {
  preview: string
}

let marked: any = null;
function renderMarkdown(value: string) {
  if (!marked) {
    marked = require('marked');
  }
  return marked(value);
}

interface IComponentProps extends IProps {
  defaultValue?: string;
}

export default class Markdown extends React.Component<IComponentProps, {}> {
  previewDiv: HTMLDivElement;

  previewHtml(e: any) {
    // get the value
    const value = e.currentTarget.value;

    // set the state and rerender
    this.previewDiv.innerHTML = renderMarkdown(value);
  }
  render() {
    return (
      <div className="field">
        <label>{config.i18n(this.props.label)}</label>
        <div className={jssClasses.boxes}>

          <div className="box box1">
            <TextArea onChange={this.previewHtml.bind(this)} {...this.props} label="" />
          </div>
          <div className="box box2">
            <div className="preview" ref={(node) => { this.previewDiv = node } }></div>
          </div>
        </div>
      </div>

    )
  }

  componentDidMount() {
    this.previewDiv.innerHTML = renderMarkdown(this.props.defaultValue);
  }

  componentDidUpdate() {
    this.previewDiv.innerHTML = renderMarkdown(this.props.defaultValue);
  }
}