import * as React from "react";
import * as css from "classnames";
import { Field, ReduxFormInput, ReduxFormMeta } from "redux-form";
import config from "../config";

export interface IProps {
  classes?: string;
  placeholder?: string;
  label?: string;
  rows?: number;
  cols?: number;
  inline?: boolean;
  name?: string;
  readOnly?: boolean;
  onChange?: Function;
  input?: ReduxFormInput;
  meta?: ReduxFormMeta;
}

class TextArea extends React.Component<IProps, {}> {
  render() {
    const { label, classes, placeholder, rows, cols, inline, name, input, meta, readOnly, onChange } = this.props;
    return (
      <div className={css("field", { inline: inline })}>
        {label ? <label>{config.i18n(label)}</label> : null}
        <textarea
          className={classes}
          placeholder={config.i18n(placeholder)}
          onChange={(e) => {
            input.onChange(e);
            if (onChange) { onChange(e); }}
          } 
          onFocus={input.onFocus}
          onDragStart={input.onDragStart}
          onDrop={input.onDrop}
          onBlur={input.onBlur}
          value={input.value}
          rows={rows}
          cols={cols}
          name={name}
          readOnly={readOnly}
          />
        {meta.touched && meta.error && <div className="redux-form-error">{meta.error}</div>}
      </div>
    )
  }
}

export default (props: IProps) => (
  <Field name={props.name} component={TextArea} {...props} />
);